/*  $Id$

    Part of XPCE --- The SWI-Prolog GUI toolkit

    Author:        Jan Wielemaker and Anjo Anjewierden
    E-mail:        jan@swi.psy.uva.nl
    WWW:           http://www.swi.psy.uva.nl/projects/xpce/
    Copyright (C): 1985-2002, University of Amsterdam

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    As a special exception, if you link this library with other files,
    compiled with a Free Software compiler, to produce an executable, this
    library does not by itself cause the resulting executable to be covered
    by the GNU General Public License. This exception does not however
    invalidate any other reasons why the executable file might be covered by
    the GNU General Public License.
*/

		 /*******************************
		 *	   PCE LIBRARY		*
		 *******************************/

/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Created  using  ?-  make_library_index(.)  in  prowindows3.2/library  by
SWI-Prolog.
- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

index((side_pattern), 3, area, area).
index((listen), 3, broadcast, broadcast).
index((listen), 2, broadcast, broadcast).
index((unlisten), 1, broadcast, broadcast).
index((unlisten), 2, broadcast, broadcast).
index((unlisten), 3, broadcast, broadcast).
index((listening), 3, broadcast, broadcast).
index((broadcast), 1, broadcast, broadcast).
index((broadcast_request), 1, broadcast, broadcast).
index((dialog), 0, dia_main, edit_dialog).
index((declare_emacs_mode), 2, emacs_extend, emacs_extend).
index((declare_emacs_mode), 3, emacs_extend, emacs_extend).
index((emacs_tag), 3, emacs_tags, emacs_tags).
index((emacs_tag_file), 1, emacs_tags, emacs_tags).
index((emacs_init_tags), 1, emacs_tags, emacs_tags).
index((emacs_complete_tag), 2, emacs_tags, emacs_tags).
index((show_key_bindings), 1, key_binding, keybinding).
index((make_dialog), 2, pce_make_dialog, make_dialog).
index((new), 2, pce, pce).
index((free), 1, pce, pce).
index((send), 2, pce, pce).
index((send), 3, pce, pce).
index((send), 4, pce, pce).
index((send), 5, pce, pce).
index((send), 6, pce, pce).
index((send), 7, pce, pce).
index((send), 8, pce, pce).
index((send), 9, pce, pce).
index((send), 10, pce, pce).
index((send), 11, pce, pce).
index((send), 12, pce, pce).
index((get), 3, pce, pce).
index((get), 4, pce, pce).
index((get), 5, pce, pce).
index((get), 6, pce, pce).
index((get), 7, pce, pce).
index((get), 8, pce, pce).
index((get), 9, pce, pce).
index((get), 10, pce, pce).
index((get), 11, pce, pce).
index((get), 12, pce, pce).
index((get), 13, pce, pce).
index((object), 1, pce, pce).
index((object), 2, pce, pce).
index((pce_open), 3, pce, pce).
index((pce_global), 2, pce, pce).
index((pce_autoload), 2, pce, pce).
index((pce_autoload_all), 0, pce, pce).
index((pce_predicate_reference), 2, pce, pce).
index((pce_term_expansion), 2, pce, pce).
index((pce_compiling), 1, pce, pce).
index((pce_begin_recording), 1, pce, pce).
index((pce_end_recording), 0, pce, pce).
index((pce_register_class), 1, pce, pce).
index((pce_extended_class), 1, pce, pce).
index((pce_prolog_class), 1, pce, pce).
index((pce_prolog_class), 2, pce, pce).
index((pce_bind_send_method), 8, pce, pce).
index((pce_bind_get_method), 9, pce, pce).
index((pce_send_method_message), 2, pce, pce).
index((pce_get_method_message), 2, pce, pce).
index((pce_catch_error), 2, pce, pce).
index((require), 1, pce, pce).
index((register_config), 1, pce_config, pce_config).
index((register_config_type), 2, pce_config, pce_config).
index((get_config), 2, pce_config, pce_config).
index((set_config), 2, pce_config, pce_config).
index((add_config), 2, pce_config, pce_config).
index((del_config), 2, pce_config, pce_config).
index((edit_config), 1, pce_config, pce_config).
index((save_config), 1, pce_config, pce_config).
index((load_config), 1, pce_config, pce_config).
index((ensure_loaded_config), 1, pce_config, pce_config).
index((config_term_to_object), 2, pce_config, pce_config).
index((config_term_to_object), 3, pce_config, pce_config).
index((config_attributes), 2, pce_config, pce_config).
index((current_config_type), 2, pce_config, pce_config).
index((generate_cpp_class_header_file), 0, pce_cpp_header, pce_cxx_headers).
index((debugpce), 0, pce_debug, pce_debug).
index((debugpce), 1, pce_debug, pce_debug).
index((nodebugpce), 0, pce_debug, pce_debug).
index((nodebugpce), 1, pce_debug, pce_debug).
index((tracepce), 0, pce_debug, pce_debug).
index((notracepce), 0, pce_debug, pce_debug).
index((tracepce), 1, pce_debug, pce_debug).
index((notracepce), 1, pce_debug, pce_debug).
index((breakpce), 1, pce_debug, pce_debug).
index((nobreakpce), 1, pce_debug, pce_debug).
index((spypce), 1, pce_debug, pce_debug).
index((nospypce), 1, pce_debug, pce_debug).
index((checkpce), 0, pce_debug, pce_debug).
index((show_slots), 1, pce_debug, pce_debug).
index((pcerefer), 1, pce_debug, pce_debug).
index((pcerefer), 2, pce_debug, pce_debug).
index((editpce), 1, pce_edit, pce_edit).
index((emacs), 0, start_emacs, pce_emacs).
index((emacs), 1, start_emacs, pce_emacs).
index((start_emacs), 0, start_emacs, pce_emacs).
index((emacs_server), 0, start_emacs, pce_emacs).
index((emacs_toplevel), 0, start_emacs, pce_emacs).
index((pce_help_file), 2, pce_help_file, pce_help_file).
index((pce_help), 2, pce_help_file, pce_help_file).
index((pce_registered_help_file), 2, pce_help_file, pce_help_file).
index((pce_image_directory), 1, pce_image, pce_image).
index((pce_load_cxx), 1, pce_load_cxx, pce_loadcxx).
index((pce_loop), 2, pce_main, pce_main).
index((pce_loop), 1, pce_main, pce_main).
index((pce_main_loop), 1, pce_main, pce_main).
index((manpce), 0, pce_manual, pce_manual).
index((manpce), 1, pce_manual, pce_manual).
index((postscript), 2, pce_postscript, pce_postscript).
index((prompter), 2, pce_prompter, pce_prompter).
index((atom_to_term), 2, pce_qux, pce_qux).
index((atom_to_term), 3, pce_qux, pce_qux).
index((term_to_atom), 2, pce_qux, pce_qux).
index((source_location), 2, pce_qux, pce_qux).
index((pce_error), 1, pce_qux, pce_qux).
index((pce_warn), 1, pce_qux, pce_qux).
index((pce_info), 1, pce_qux, pce_qux).
index((ignore), 1, pce_qux, pce_qux).
index((auto_call), 1, pce_qux, pce_qux).
index((concat), 3, pce_qux, pce_qux).
index((free_variables), 2, pce_qux, pce_qux).
index((atom_length), 2, pce_qux, pce_qux).
index((time_file), 2, pce_qux, pce_qux).
index((strip_module), 3, pce_qux, pce_qux).
index((pce_arg), 3, pce_qux, pce_qux).
index((sublist), 3, pce_qux, pce_qux).
index((exists_file), 1, pce_qux, pce_qux).
index((make), 0, pce_qux, pce_qux).
index((source_warning), 2, pce_qux, pce_qux).
index((sformat), 3, pce_qux, pce_qux).
index((is_absolute_file_name), 1, pce_qux, pce_qux).
index((file_directory_name), 2, pce_qux, pce_qux).
index((file_base_name), 2, pce_qux, pce_qux).
index((file_name_extension), 3, pce_qux, pce_qux).
index((expand_file_name), 2, pce_qux, pce_qux).
index((callable_predicate), 1, pce_qux, pce_qux).
index((modified_since_last_loaded), 1, pce_qux, pce_qux).
index((notrace), 1, pce_qux, pce_qux).
index((xpce_loop), 0, pce_qux, pce_qux).
index((pce_renew), 1, pce_renew, pce_renew).
index((pce_require), 1, pce_require, pce_require).
index((pce_require), 3, pce_require, pce_require).
index((pce_server), 1, pce_server, pce_server).
index((pce_shell_command), 1, pce_shell, pce_shell).
index((use_class_template), 1, pce_class_template, pce_template).
index((use_class_template), 2, pce_class_template, pce_template).
index((get_object), 3, pce_util, pce_util).
index((get_object), 4, pce_util, pce_util).
index((get_object), 5, pce_util, pce_util).
index((get_object), 6, pce_util, pce_util).
index((get_object), 7, pce_util, pce_util).
index((get_object), 8, pce_util, pce_util).
index((get_object), 9, pce_util, pce_util).
index((get_object), 10, pce_util, pce_util).
index((get_object), 11, pce_util, pce_util).
index((get_object), 12, pce_util, pce_util).
index((get_object), 13, pce_util, pce_util).
index((send_list), 2, pce_util, pce_util).
index((send_list), 3, pce_util, pce_util).
index((get_chain), 3, pce_util, pce_util).
index((chain_list), 2, pce_util, pce_util).
index((default), 3, pce_util, pce_util).
index((pcedraw), 0, pce_draw, pcedraw).
index((pcedraw), 1, pce_draw, pcedraw).
index((save_pcedraw), 1, pce_draw, pcedraw).
index((portray_object), 1, pce_portray, portray_object).
index((portray_object), 2, pce_portray, portray_object).
index((scan_arguments), 2, scan_arguments, scan_arguments).
index((scan_arguments), 3, scan_arguments, scan_arguments).

		 /*******************************
		 *	 QUINTUS LIBRARY	*
		 *******************************/

index((add_portray), 1, add_portray, add_portray).
index((del_portray), 1, add_portray, add_portray).
index((add_expansion), 1, add_portray, add_portray).
index((del_expansion), 1, add_portray, add_portray).
index((add_linking_clause), 3, add_portray, add_portray).
index((del_linking_clause), 3, add_portray, add_portray).
index((add_portray), 1, add_portray, addportray).
index((del_portray), 1, add_portray, addportray).
index((add_expansion), 1, add_portray, addportray).
index((del_expansion), 1, add_portray, addportray).
index((add_linking_clause), 3, add_portray, addportray).
index((del_linking_clause), 3, add_portray, addportray).
index((aggregate), 3, aggregate, aggregate).
index((aggregate), 4, aggregate, aggregate).
index((aggregate_all), 3, aggregate, aggregate).
index((aggregate_all), 4, aggregate, aggregate).
index((anti_unify), 3, anti_unify, anti_unify).
index((anti_unify), 5, anti_unify, anti_unify).
index((anti_unify), 3, anti_unify, antiunify).
index((anti_unify), 5, anti_unify, antiunify).
index((ar_open), 3, ar_open, ar_open).
index((arg0), 3, arg, arg).
index((args), 3, arg, arg).
index((args0), 3, arg, arg).
index((genarg), 3, arg, arg).
index((genarg0), 3, arg, arg).
index((path_arg), 3, arg, arg).
index((project), 3, arg, arg).
index((arity_argrep), 4, arity, arity).
index((arity_apology), 1, arity, arity).
index((arity_command), 2, arity, arity).
index((arity_date), 1, arity, arity).
index((arity_date_day), 2, arity, arity).
index((arity_keys), 1, arity, arity).
index((arity_open), 3, arity, arity).
index((arity_randomise), 1, arity, arity).
index((arity_random), 1, arity, arity).
index((arity_ref), 1, arity, arity).
index((arity_seek), 4, arity, arity).
index((arity_system), 1, arity, arity).
index((arity_time), 1, arity, arity).
index((inc), 2, arity, arity).
index((dec), 2, arity, arity).
index((current_predicate), 1, arity, arity).
index((reset_op), 0, arity, arity).
index((ar_open), 3, ar_open, aropen).
index((array_length), 2, arrays, arrays).
index((array_to_list), 2, arrays, arrays).
index((array_fetch), 3, arrays, arrays).
index((list_to_array), 2, arrays, arrays).
index((list_to_array), 3, arrays, arrays).
index((array_store), 4, arrays, arrays).
index((ask), 2, ask, ask).
index((ask), 3, ask, ask).
index((ask_between), 4, ask, ask).
index((ask_between), 5, ask, ask).
index((ask_chars), 4, ask, ask).
index((ask_default_character), 2, ask, ask).
index((ask_file), 2, ask, ask).
index((ask_file), 3, ask, ask).
index((ask_number), 2, ask, ask).
index((ask_number), 3, ask, ask).
index((ask_number), 4, ask, ask).
index((ask_number), 5, ask, ask).
index((ask_oneof), 3, ask, ask).
index((ask_oneof), 4, ask, ask).
index((yesno), 1, ask, ask).
index((yesno), 2, ask, ask).
index((assoc_to_list), 2, assoc, assoc).
index((gen_assoc), 3, assoc, assoc).
index((get_assoc), 3, assoc, assoc).
index((get_next_assoc), 4, assoc, assoc).
index((get_prev_assoc), 4, assoc, assoc).
index((is_assoc), 1, assoc, assoc).
index((list_to_assoc), 2, assoc, assoc).
index((ord_list_to_assoc), 2, assoc, assoc).
index((map_assoc), 2, assoc, assoc).
index((map_assoc), 3, assoc, assoc).
index((max_assoc), 3, assoc, assoc).
index((min_assoc), 3, assoc, assoc).
index((portray_assoc), 1, assoc, assoc).
index((put_assoc), 4, assoc, assoc).
index((avl_to_list), 2, avl, avl).
index((is_avl), 1, avl, avl).
index((avl_change), 5, avl, avl).
index((avl_domain), 2, avl, avl).
index((avl_fetch), 2, avl, avl).
index((avl_fetch), 3, avl, avl).
index((avl_height), 2, avl, avl).
index((avl_incr), 4, avl, avl).
index((avl_max), 2, avl, avl).
index((avl_max), 3, avl, avl).
index((avl_member), 2, avl, avl).
index((avl_member), 3, avl, avl).
index((avl_min), 2, avl, avl).
index((avl_min), 3, avl, avl).
index((avl_next), 3, avl, avl).
index((avl_next), 4, avl, avl).
index((avl_prev), 3, avl, avl).
index((avl_prev), 4, avl, avl).
index((avl_range), 2, avl, avl).
index((avl_size), 2, avl, avl).
index((avl_store), 4, avl, avl).
index((empty_avl), 1, avl, avl).
index((list_to_avl), 2, avl, avl).
index((ord_list_to_avl), 2, avl, avl).
index((portray_avl), 1, avl, avl).
index((bag_add_element), 3, bags, bags).
index((bag_add_element), 4, bags, bags).
index((bag_del_element), 3, bags, bags).
index((bag_del_element), 4, bags, bags).
index((bag_intersect), 2, bags, bags).
index((bag_intersection), 2, bags, bags).
index((bag_intersection), 3, bags, bags).
index((bag_max), 2, bags, bags).
index((bag_max), 3, bags, bags).
index((bag_min), 2, bags, bags).
index((bag_min), 3, bags, bags).
index((bag_subtract), 3, bags, bags).
index((bag_to_list), 2, bags, bags).
index((bag_to_ord_set), 2, bags, bags).
index((bag_to_ord_set), 3, bags, bags).
index((bag_to_set), 2, bags, bags).
index((bag_to_set), 3, bags, bags).
index((bag_union), 2, bags, bags).
index((bag_union), 3, bags, bags).
index((checkbag), 2, bags, bags).
index((empty_bag), 1, bags, bags).
index((is_bag), 1, bags, bags).
index((length), 3, bags, bags).
index((list_to_bag), 2, bags, bags).
index((make_sub_bag), 2, bags, bags).
index((mapbag), 2, bags, bags).
index((mapbag), 3, bags, bags).
index((member), 3, bags, bags).
index((memberchk), 3, bags, bags).
index((portray_bag), 1, bags, bags).
index((somebag), 2, bags, bags).
index((somechkbag), 2, bags, bags).
index((test_sub_bag), 2, bags, bags).
index((member), 2, basics, basics).
index((memberchk), 2, basics, basics).
index((nonmember), 2, basics, basics).
index((time), 1, benchmark, benchmark).
index((time), 2, benchmark, benchmark).
index((time), 3, benchmark, benchmark).
index((time), 15, benchmark, benchmark).
index((between), 3, between, between).
index((gen_int), 1, between, between).
index((gen_nat), 1, between, between).
index((numlist), 3, between, between).
index((repeat), 1, between, between).
index((is_big_text), 1, big_text, big_text).
index((copy_texts), 3, big_text, big_text).
index((edit_text), 3, big_text, big_text).
index((edit_text), 4, big_text, big_text).
index((have_emacs_edit), 1, big_text, big_text).
index((have_emacs_edit), 2, big_text, big_text).
index((make_big_text), 2, big_text, big_text).
index((make_big_text), 3, big_text, big_text).
index((make_big_text), 4, big_text, big_text).
index((pipe_to_text), 3, big_text, big_text).
index((send_editor), 2, big_text, big_text).
index((show_text), 1, big_text, big_text).
index((text_to_file), 2, big_text, big_text).
index((text_to_pipe), 2, big_text, big_text).
index((is_bitset), 1, bitsets, bitsets).
index((bitset_ordset), 2, bitsets, bitsets).
index((bitset_to_list), 2, bitsets, bitsets).
index((list_to_bitset), 2, bitsets, bitsets).
index((bit_add_element), 3, bitsets, bitsets).
index((bit_card), 2, bitsets, bitsets).
index((bit_del_element), 3, bitsets, bitsets).
index((bit_disjoint), 2, bitsets, bitsets).
index((bit_intersect), 2, bitsets, bitsets).
index((bit_intersection), 2, bitsets, bitsets).
index((bit_intersection), 3, bitsets, bitsets).
index((bit_member), 2, bitsets, bitsets).
index((bit_memberchk), 2, bitsets, bitsets).
index((bit_seteq), 2, bitsets, bitsets).
index((bit_subtract), 3, bitsets, bitsets).
index((bit_symdiff), 3, bitsets, bitsets).
index((bit_union), 2, bitsets, bitsets).
index((bit_union), 3, bitsets, bitsets).
index((error_break), 2, break, break).
index((apply), 2, call, call).
index((call), 2, call, call).
index((call), 3, call, call).
index((call), 4, call, call).
index((call), 5, call, call).
index((call), 6, call, call).
index((call), 7, call, call).
index((strip_module_prefix), 4, call, call).
index((lower), 1, caseconv, case_conv).
index((lower), 2, caseconv, case_conv).
index((mixed), 1, caseconv, case_conv).
index((mixed), 2, caseconv, case_conv).
index((upper), 1, caseconv, case_conv).
index((upper), 2, caseconv, case_conv).
index((lower_upper), 2, caseconv, case_conv).
index((lower), 1, caseconv, caseconv).
index((lower), 2, caseconv, caseconv).
index((mixed), 1, caseconv, caseconv).
index((mixed), 2, caseconv, caseconv).
index((upper), 1, caseconv, caseconv).
index((upper), 2, caseconv, caseconv).
index((lower_upper), 2, caseconv, caseconv).
index((cassert), 1, cassert, cassert).
index((casserta), 1, cassert, cassert).
index((cassertz), 1, cassert, cassert).
index((change_arg), 4, change_arg, change_arg).
index((change_arg), 5, change_arg, change_arg).
index((change_arg0), 4, change_arg, change_arg).
index((change_arg0), 5, change_arg, change_arg).
index((change_functor), 5, change_arg, change_arg).
index((change_path_arg), 4, change_arg, change_arg).
index((change_path_arg), 5, change_arg, change_arg).
index((swap_args), 4, change_arg, change_arg).
index((swap_args), 6, change_arg, change_arg).
index((change_arg), 4, change_arg, changearg).
index((change_arg), 5, change_arg, changearg).
index((change_arg0), 4, change_arg, changearg).
index((change_arg0), 5, change_arg, changearg).
index((change_functor), 5, change_arg, changearg).
index((change_path_arg), 4, change_arg, changearg).
index((change_path_arg), 5, change_arg, changearg).
index((swap_args), 4, change_arg, changearg).
index((swap_args), 6, change_arg, changearg).
index((chars_to_stream), 2, charsio, charsio).
index((chars_to_term), 2, charsio, charsio).
index((term_to_chars), 2, charsio, charsio).
index((with_input_from_chars), 2, charsio, charsio).
index((with_input_from_chars), 3, charsio, charsio).
index((with_output_to_chars), 3, charsio, charsio).
index((with_output_to_chars), 2, charsio, charsio).
index((clumped), 2, clump, clump).
index((clumps), 2, clump, clump).
index((keyclumped), 2, clump, clump).
index((keyclumps), 2, clump, clump).
index((read_oper_continued_line), 1, continued, continued).
index((read_unix_continued_line), 1, continued, continued).
index((count), 1, count, count).
index((clear_counts), 0, count, count).
index((write_counts), 1, count, count).
index((increment_), 1, count, count).
index((make_counter), 2, counter, counter).
index((counter_bound), 2, counter, counter).
index((counter_value), 2, counter, counter).
index((decrement_counter), 1, counter, counter).
index((decrement_counter), 2, counter, counter).
index((is_counter), 1, counter, counter).
index((portray_counter), 1, counter, counter).
index((critical), 1, critical, critical).
index((critical_on_exception), 3, critical, critical).
index((begin_critical), 0, critical, critical).
index((end_critical), 0, critical, critical).
index((crypt_open), 3, crypt, crypt).
index((crypt_open), 4, crypt, crypt).
index((ctr_set), 2, ctr, ctr).
index((ctr_set), 3, ctr, ctr).
index((ctr_inc), 1, ctr, ctr).
index((ctr_inc), 2, ctr, ctr).
index((ctr_inc), 3, ctr, ctr).
index((ctr_dec), 1, ctr, ctr).
index((ctr_dec), 2, ctr, ctr).
index((ctr_dec), 3, ctr, ctr).
index((ctr_is), 2, ctr, ctr).
index((is_alnum), 1, ctypes, ctypes).
index((is_alpha), 1, ctypes, ctypes).
index((is_ascii), 1, ctypes, ctypes).
index((is_char), 1, ctypes, ctypes).
index((is_cntrl), 1, ctypes, ctypes).
index((is_csym), 1, ctypes, ctypes).
index((is_csymf), 1, ctypes, ctypes).
index((is_digit), 1, ctypes, ctypes).
index((is_digit), 2, ctypes, ctypes).
index((is_digit), 3, ctypes, ctypes).
index((is_endfile), 1, ctypes, ctypes).
index((is_endline), 1, ctypes, ctypes).
index((is_graph), 1, ctypes, ctypes).
index((is_layout), 1, ctypes, ctypes).
index((is_lower), 1, ctypes, ctypes).
index((is_newline), 1, ctypes, ctypes).
index((is_newpage), 1, ctypes, ctypes).
index((is_paren), 2, ctypes, ctypes).
index((is_period), 1, ctypes, ctypes).
index((is_print), 1, ctypes, ctypes).
index((is_punct), 1, ctypes, ctypes).
index((is_quote), 1, ctypes, ctypes).
index((is_space), 1, ctypes, ctypes).
index((is_upper), 1, ctypes, ctypes).
index((is_white), 1, ctypes, ctypes).
index((to_lower), 2, ctypes, ctypes).
index((to_upper), 2, ctypes, ctypes).
index((ctypes_bits), 2, ctypes, ctypes).
index((date), 1, date, date).
index((date), 2, date, date).
index((date), 3, date, date).
index((now), 1, date, date).
index((time), 1, date, date).
index((time), 2, date, date).
index((time), 3, date, date).
index((datime), 1, date, date).
index((datime), 2, date, date).
index((datime), 3, date, date).
index((datime), 6, date, date).
index((datime), 7, date, date).
index((date_and_time), 2, date, date).
index((date_and_time), 3, date, date).
index((time_stamp), 2, date, date).
index((time_stamp), 3, date, date).
index((portray_date), 1, date, date).
index((prolog_bounded_quantification), 3, decons, decons).
index((prolog_clause), 3, decons, decons).
index((prolog_conjunction), 2, decons, decons).
index((prolog_disjunction), 2, decons, decons).
index((prolog_if_branch), 3, decons, decons).
index((prolog_if_then_else), 4, decons, decons).
index((prolog_negation), 2, decons, decons).
index((current_directory), 1, directory, directory).
index((directory_member_of_directory), 2, directory, directory).
index((directory_member_of_directory), 3, directory, directory).
index((directory_member_of_directory), 4, directory, directory).
index((directory_members_of_directory), 1, directory, directory).
index((directory_members_of_directory), 2, directory, directory).
index((directory_members_of_directory), 3, directory, directory).
index((directory_property), 2, directory, directory).
index((directory_property), 3, directory, directory).
index((file_member_of_directory), 2, directory, directory).
index((file_member_of_directory), 3, directory, directory).
index((file_member_of_directory), 4, directory, directory).
index((file_members_of_directory), 1, directory, directory).
index((file_members_of_directory), 2, directory, directory).
index((file_members_of_directory), 3, directory, directory).
index((file_property), 2, directory, directory).
index((file_property), 3, directory, directory).
index((is_alnum), 1, ctypes, ebctypes).
index((is_alpha), 1, ctypes, ebctypes).
index((is_ascii), 1, ctypes, ebctypes).
index((is_char), 1, ctypes, ebctypes).
index((is_cntrl), 1, ctypes, ebctypes).
index((is_csym), 1, ctypes, ebctypes).
index((is_csymf), 1, ctypes, ebctypes).
index((is_digit), 1, ctypes, ebctypes).
index((is_digit), 3, ctypes, ebctypes).
index((is_ebcdic), 1, ctypes, ebctypes).
index((is_endfile), 1, ctypes, ebctypes).
index((is_endline), 1, ctypes, ebctypes).
index((is_graph), 1, ctypes, ebctypes).
index((is_lower), 1, ctypes, ebctypes).
index((is_newline), 1, ctypes, ebctypes).
index((is_newpage), 1, ctypes, ebctypes).
index((is_paren), 2, ctypes, ebctypes).
index((is_period), 1, ctypes, ebctypes).
index((is_print), 1, ctypes, ebctypes).
index((is_punct), 1, ctypes, ebctypes).
index((is_quote), 1, ctypes, ebctypes).
index((is_space), 1, ctypes, ebctypes).
index((is_upper), 1, ctypes, ebctypes).
index((to_lower), 2, ctypes, ebctypes).
index((to_upper), 2, ctypes, ebctypes).
index((argv), 1, environ, environ).
index((environ), 2, environ, environ).
index((expanded_file_name), 2, environ, environ).
index((environment), 1, environment, environment).
index((errno), 2, errno, errno).
index((errno), 3, errno, errno).
index((fileerrno), 2, errno, errno).
index((exit), 0, exit, exit).
index((exit), 1, exit, exit).
index((fwd_fft), 2, fft, fft).
index((inv_fft), 2, fft, fft).
index((filename), 1, file_name, file_name).
index((filename), 2, file_name, file_name).
index((filename), 3, file_name, file_name).
index((filename_atom), 2, file_name, file_name).
index((filename_atom), 3, file_name, file_name).
index((filename_chars), 2, file_name, file_name).
index((filename_chars), 3, file_name, file_name).
index((filename_chars), 4, file_name, file_name).
index((filename_string), 2, file_name, file_name).
index((filename_string), 3, file_name, file_name).
index((filename_directory), 4, file_name, file_name).
index((open_file), 3, file_name, file_name).
index((portray_filename), 1, file_name, file_name).
index((filename), 1, file_name, filename).
index((filename), 2, file_name, filename).
index((filename), 3, file_name, filename).
index((filename_atom), 2, file_name, filename).
index((filename_atom), 3, file_name, filename).
index((filename_chars), 2, file_name, filename).
index((filename_chars), 3, file_name, filename).
index((filename_chars), 4, file_name, filename).
index((filename_string), 2, file_name, filename).
index((filename_string), 3, file_name, filename).
index((filename_directory), 4, file_name, filename).
index((open_file), 3, file_name, filename).
index((portray_filename), 1, file_name, filename).
index((can_open_file), 2, files, files).
index((can_open_file), 3, files, files).
index((close_all_streams), 0, files, files).
index((current_dec10_stream), 2, files, files).
index((delete_file), 1, files, files).
index((directory_exists), 1, files, files).
index((directory_exists), 2, files, files).
index((file_exists), 1, files, files).
index((file_exists), 2, files, files).
index((file_must_exist), 1, files, files).
index((file_must_exist), 2, files, files).
index((open_file), 3, files, files).
index((dec10_rename), 2, files, files).
index((rename), 2, files, files).
index((rename_file), 2, files, files).
index((findall), 4, findall, findall).
index((and_to_list), 2, flatten, flatten).
index((list_to_and), 2, flatten, flatten).
index((or_to_list), 2, flatten, flatten).
index((list_to_or), 2, flatten, flatten).
index((plus_to_list), 2, flatten, flatten).
index((list_to_plus), 2, flatten, flatten).
index((times_to_list), 2, flatten, flatten).
index((list_to_times), 2, flatten, flatten).
index((flatten), 2, flatten, flatten).
index((binary_to_list), 4, flatten, flatten).
index((binary_to_list), 5, flatten, flatten).
index((list_to_binary), 3, flatten, flatten).
index((list_to_binary), 4, flatten, flatten).
index((forall), 2, foreach, foreach).
index((foreach), 2, foreach, foreach).
index((free_variables), 4, free_variables, freevars).
index((term_variables), 3, free_variables, freevars).
index((from_chars), 2, fromonto, fromonto).
index((onto_chars), 2, fromonto, fromonto).
index((from_file), 2, fromonto, fromonto).
index((onto_file), 2, fromonto, fromonto).
index((from_stream), 2, fromonto, fromonto).
index((onto_stream), 2, fromonto, fromonto).
index((copy_bytes), 0, fromonto, fromonto).
index((writeln), 1, fromonto, fromonto).
index(('fuzzy <'), 2, fuzzy, fuzzy).
index(('fuzzy ~'), 2, fuzzy, fuzzy).
index(('fuzzy >'), 2, fuzzy, fuzzy).
index(('fuzzy ='), 2, fuzzy, fuzzy).
index((set_fuzz), 1, fuzzy, fuzzy).
index((gauss), 3, gauss, gauss).
index((get_file), 2, get_file, get_file).
index((get_file), 2, get_file, getfile).
index((f_to_p_graph), 2, graphs, graphs).
index((f_to_s_graph), 2, graphs, graphs).
index((p_to_f_graph), 2, graphs, graphs).
index((p_to_s_graph), 2, graphs, graphs).
index((s_to_f_graph), 2, graphs, graphs).
index((s_to_p_graph), 2, graphs, graphs).
index((s_to_p_trans), 2, graphs, graphs).
index((p_length), 2, graphs, graphs).
index((s_length), 2, graphs, graphs).
index((p_member), 3, graphs, graphs).
index((s_member), 3, graphs, graphs).
index((p_transpose), 2, graphs, graphs).
index((s_transpose), 2, graphs, graphs).
index((compose), 3, graphs, graphs).
index((reachable), 3, graphs, graphs).
index((top_sort), 2, graphs, graphs).
index((p_vertices), 2, graphs, graphs).
index((s_vertices), 2, graphs, graphs).
index((warshall), 2, graphs, graphs).
index((add_to_heap), 4, heaps, heaps).
index((empty_heap), 1, heaps, heaps).
index((get_from_heap), 4, heaps, heaps).
index((heap_size), 2, heaps, heaps).
index((heap_to_list), 2, heaps, heaps).
index((is_heap), 1, heaps, heaps).
index((list_to_heap), 2, heaps, heaps).
index((min_of_heap), 3, heaps, heaps).
index((min_of_heap), 5, heaps, heaps).
index((portray_heap), 1, heaps, heaps).
index((assertz_hook), 2, hooks, hooks).
index((asserta_hook), 2, hooks, hooks).
index((assertz_hook), 3, hooks, hooks).
index((asserta_hook), 3, hooks, hooks).
index((retract_hook), 2, hooks, hooks).
index((current_hook), 2, hooks, hooks).
index((add_fact), 1, indexer, indexer).
index((del_all), 1, indexer, indexer).
index((del_fact), 1, indexer, indexer).
index((eof_kee), 1, kee, kee).
index((load_kee), 2, kee, kee).
index((read_kee), 1, kee, kee).
index((vars_kee), 4, kee, kee).
index((write_kee), 1, kee, kee).
index((constant), 2, knuth_b_1, knuth_b_1).
index((append_length), 3, length, length).
index((append_length), 4, length, length).
index((prefix_length), 3, length, length).
index((proper_prefix_length), 3, length, length).
index((proper_suffix_length), 3, length, length).
index((rotate_list), 2, length, length).
index((rotate_list), 3, length, length).
index((suffix_length), 3, length, length).
index((sublist), 3, length, length).
index((sublist), 4, length, length).
index((sublist), 5, length, length).
index((tree_level), 3, level, level).
index((tree_level_labels), 3, level, level).
index((term_level), 3, level, level).
index((term_level_labels), 3, level, level).
index((get_line), 1, lineio, line_io).
index((fget_line), 2, lineio, line_io).
index((get_line), 2, lineio, line_io).
index((fget_line), 3, lineio, line_io).
index((put_chars), 1, lineio, line_io).
index((put_line), 1, lineio, line_io).
index((get_line), 1, lineio, lineio).
index((fget_line), 2, lineio, lineio).
index((get_line), 2, lineio, lineio).
index((fget_line), 3, lineio, lineio).
index((put_chars), 1, lineio, lineio).
index((put_line), 1, lineio, lineio).
index((cons), 3, list_parts, list_parts).
index((last), 3, list_parts, list_parts).
index((head), 2, list_parts, list_parts).
index((tail), 2, list_parts, list_parts).
index((prefix), 2, list_parts, list_parts).
index((proper_prefix), 2, list_parts, list_parts).
index((suffix), 2, list_parts, list_parts).
index((proper_suffix), 2, list_parts, list_parts).
index((segment), 2, list_parts, list_parts).
index((proper_segment), 2, list_parts, list_parts).
index((sublist), 2, list_parts, list_parts).
index((proper_sublist), 2, list_parts, list_parts).
index((cons), 3, list_parts, listparts).
index((last), 3, list_parts, listparts).
index((head), 2, list_parts, listparts).
index((tail), 2, list_parts, listparts).
index((prefix), 2, list_parts, listparts).
index((proper_prefix), 2, list_parts, listparts).
index((suffix), 2, list_parts, listparts).
index((proper_suffix), 2, list_parts, listparts).
index((segment), 2, list_parts, listparts).
index((proper_segment), 2, list_parts, listparts).
index((sublist), 2, list_parts, listparts).
index((proper_sublist), 2, list_parts, listparts).
index((append), 2, lists, lists).
index((append), 5, lists, lists).
index((correspond), 4, lists, lists).
index((delete), 3, lists, lists).
index((delete), 4, lists, lists).
index((is_list), 1, lists, lists).
index((keys_and_values), 3, lists, lists).
index((last), 2, lists, lists).
index((nextto), 3, lists, lists).
index((nmember), 3, lists, lists).
index((nth0), 3, lists, lists).
index((nth0), 4, lists, lists).
index((nth1), 3, lists, lists).
index((nth1), 4, lists, lists).
index((one_longer), 2, lists, lists).
index((perm), 2, lists, lists).
index((perm2), 4, lists, lists).
index((permutation), 2, lists, lists).
index((proper_length), 2, lists, lists).
index((remove_dups), 2, lists, lists).
index((rev), 2, lists, lists).
index((reverse), 2, lists, lists).
index((same_length), 2, lists, lists).
index((same_length), 3, lists, lists).
index((select), 4, lists, lists).
index((selectchk), 4, lists, lists).
index((shorter_list), 2, lists, lists).
index((subseq), 3, lists, lists).
index((subseq0), 2, lists, lists).
index((subseq1), 2, lists, lists).
index((sumlist), 2, lists, lists).
index((transpose), 2, lists, lists).
index((integer_chars), 2, load, load).
index((load), 3, load, load).
index((load_record), 1, load, load).
index((new_array), 1, logarr, logarr).
index((is_array), 1, logarr, logarr).
index((aref), 3, logarr, logarr).
index((arefa), 3, logarr, logarr).
index((arefl), 3, logarr, logarr).
index((aset), 4, logarr, logarr).
index((alist), 2, logarr, logarr).
index((rational), 1, long, long).
index((whole), 1, long, long).
index((eval), 1, long, long).
index((eval), 2, long, long).
index((eq), 2, long, long).
index((ge), 2, long, long).
index((gt), 2, long, long).
index((le), 2, long, long).
index((lt), 2, long, long).
index((ne), 2, long, long).
index((portray_number), 1, long, long).
index((succ), 2, long, long).
index((plus), 3, long, long).
index((times), 3, long, long).
index((power), 3, long, long).
index((floor), 2, long, long).
index((floor), 3, long, long).
index((floor), 4, long, long).
index((ceiling), 2, long, long).
index((ceiling), 3, long, long).
index((ceiling), 4, long, long).
index((round), 2, long, long).
index((round), 3, long, long).
index((round), 4, long, long).
index((truncate), 2, long, long).
index((truncate), 3, long, long).
index((truncate), 4, long, long).
index((checkand), 2, mapand, mapand).
index((mapand), 3, mapand, mapand).
index((checklist), 2, maplist, maplist).
index((cumlist), 4, maplist, maplist).
index((cumlist), 5, maplist, maplist).
index((cumlist), 6, maplist, maplist).
index((maplist), 2, maplist, maplist).
index((maplist), 3, maplist, maplist).
index((maplist), 4, maplist, maplist).
index((map_product), 4, maplist, maplist).
index((scanlist), 4, maplist, maplist).
index((scanlist), 5, maplist, maplist).
index((scanlist), 6, maplist, maplist).
index((some), 2, maplist, maplist).
index((some), 3, maplist, maplist).
index((some), 4, maplist, maplist).
index((somechk), 2, maplist, maplist).
index((somechk), 3, maplist, maplist).
index((somechk), 4, maplist, maplist).
index((map_queue), 2, mapqueue, mapqueue).
index((map_queue), 3, mapqueue, mapqueue).
index((map_queue_list), 3, mapqueue, mapqueue).
index((map_list_queue), 3, mapqueue, mapqueue).
index((some_queue), 2, mapqueue, mapqueue).
index((some_queue), 3, mapqueue, mapqueue).
index((somechk_queue), 2, mapqueue, mapqueue).
index((somechk_queue), 3, mapqueue, mapqueue).
index((is_map), 1, maps, maps).
index((list_to_map), 2, maps, maps).
index((map_agree), 2, maps, maps).
index((map_compose), 3, maps, maps).
index((map_disjoint), 2, maps, maps).
index((map_domain), 2, maps, maps).
index((map_exclude), 3, maps, maps).
index((map_include), 3, maps, maps).
index((map_intersection), 3, maps, maps).
index((map_invert), 2, maps, maps).
index((map_map), 3, maps, maps).
index((map_range), 2, maps, maps).
index((map_to_assoc), 2, maps, maps).
index((map_to_list), 2, maps, maps).
index((map_union), 3, maps, maps).
index((map_update), 3, maps, maps).
index((map_update), 4, maps, maps).
index((map_value), 3, maps, maps).
index((portray_map), 1, maps, maps).
index((exp), 2, math, math).
index((log), 2, math, math).
index((log10), 2, math, math).
index((pow), 3, math, math).
index((sqrt), 2, math, math).
index((gamma), 2, math, math).
index((hypot), 3, math, math).
index((abs), 2, math, math).
index((fabs), 2, math, math).
index((j0), 2, math, math).
index((j1), 2, math, math).
index((jn), 3, math, math).
index((y0), 2, math, math).
index((y1), 2, math, math).
index((yn), 3, math, math).
index((sin), 2, math, math).
index((asin), 2, math, math).
index((sinh), 2, math, math).
index((asinh), 2, math, math).
index((cos), 2, math, math).
index((acos), 2, math, math).
index((cosh), 2, math, math).
index((acosh), 2, math, math).
index((tan), 2, math, math).
index((atan), 2, math, math).
index((tanh), 2, math, math).
index((atanh), 2, math, math).
index((atan2), 3, math, math).
index((max), 3, math, math).
index((min), 3, math, math).
index((sign), 2, math, math).
index((sign), 3, math, math).
index((scale), 3, math, math).
index((decode_float), 4, math, math).
index((floor), 2, math, math).
index((floor), 3, math, math).
index((ffloor), 2, math, math).
index((ffloor), 3, math, math).
index((truncate), 2, math, math).
index((truncate), 3, math, math).
index((ftruncate), 2, math, math).
index((ftruncate), 3, math, math).
index((ceiling), 2, math, math).
index((ceiling), 3, math, math).
index((fceiling), 2, math, math).
index((fceiling), 3, math, math).
index((round), 2, math, math).
index((round), 3, math, math).
index((fround), 2, math, math).
index((fround), 3, math, math).
index((fremainder), 3, math, math).
index((ceil), 2, math, math).
index((cabs), 2, math, math).
index((menu_choice), 2, menu, menu).
index((menu_choice), 3, menu, menu).
index((menu_number), 3, menu, menu).
index((send_editor), 1, menu, menu).
index((adjust), 5, more_lists, more_lists).
index((adjust), 6, more_lists, more_lists).
index((bnd), 2, more_lists, more_lists).
index((bnd), 3, more_lists, more_lists).
index((bnd), 4, more_lists, more_lists).
index((len), 2, more_lists, more_lists).
index((len), 3, more_lists, more_lists).
index((len), 4, more_lists, more_lists).
index((lit), 3, more_lists, more_lists).
index((oneof), 3, more_lists, more_lists).
index((oneof), 4, more_lists, more_lists).
index((replist), 2, more_lists, more_lists).
index((replist), 3, more_lists, more_lists).
index((replist), 4, more_lists, more_lists).
index((spaces), 2, more_lists, more_lists).
index((spaces), 3, more_lists, more_lists).
index((convlist), 3, more_maps, more_maps).
index((exclude), 3, more_maps, more_maps).
index((exclude), 4, more_maps, more_maps).
index((exclude), 5, more_maps, more_maps).
index((include), 3, more_maps, more_maps).
index((include), 4, more_maps, more_maps).
index((include), 5, more_maps, more_maps).
index((partition), 5, more_maps, more_maps).
index((group), 3, more_maps, more_maps).
index((group), 4, more_maps, more_maps).
index((group), 5, more_maps, more_maps).
index((adjust), 5, more_lists, morelists).
index((adjust), 6, more_lists, morelists).
index((bnd), 2, more_lists, morelists).
index((bnd), 3, more_lists, morelists).
index((bnd), 4, more_lists, morelists).
index((len), 2, more_lists, morelists).
index((len), 3, more_lists, morelists).
index((len), 4, more_lists, morelists).
index((lit), 3, more_lists, morelists).
index((oneof), 3, more_lists, morelists).
index((oneof), 4, more_lists, morelists).
index((replist), 2, more_lists, morelists).
index((replist), 3, more_lists, morelists).
index((replist), 4, more_lists, morelists).
index((spaces), 2, more_lists, morelists).
index((spaces), 3, more_lists, morelists).
index((convlist), 3, more_maps, moremaps).
index((exclude), 3, more_maps, moremaps).
index((exclude), 4, more_maps, moremaps).
index((exclude), 5, more_maps, moremaps).
index((include), 3, more_maps, moremaps).
index((include), 4, more_maps, moremaps).
index((include), 5, more_maps, moremaps).
index((partition), 5, more_maps, moremaps).
index((group), 3, more_maps, moremaps).
index((group), 4, more_maps, moremaps).
index((group), 5, more_maps, moremaps).
index((first_mst), 4, mst, mst).
index((mst), 4, mst, mst).
index((ml_maplist), 2, multi_lists, multil).
index((ml_maplist), 3, multi_lists, multil).
index((ml_maplist), 4, multi_lists, multil).
index((ml_member), 2, multi_lists, multil).
index((ml_memberchk), 2, multi_lists, multil).
index((ml_select), 3, multi_lists, multil).
index((append_queue), 3, queues, newqueues).
index((empty_queue), 1, queues, newqueues).
index((is_queue), 1, queues, newqueues).
index((list_queue), 2, queues, newqueues).
index((portray_queue), 1, queues, newqueues).
index((queue_append), 3, queues, newqueues).
index((queue_cons), 3, queues, newqueues).
index((queue_head), 2, queues, newqueues).
index((queue_last), 2, queues, newqueues).
index((queue_last), 3, queues, newqueues).
index((queue_length), 2, queues, newqueues).
index((queue_list), 2, queues, newqueues).
index((queue_member), 2, queues, newqueues).
index((queue_memberchk), 2, queues, newqueues).
index((nlist), 3, nlist, nlist).
index((\=), 2, negation, not).
index((~=), 2, negation, not).
index((once), 1, negation, not).
index((not), 1, negation, not).
index((note), 2, note, note).
index((note), 3, note, note).
index((notea), 2, note, note).
index((notea), 3, note, note).
index((notez), 2, note, note).
index((notez), 3, note, note).
index((noted), 2, note, note).
index((noted), 3, note, note).
index((scrap), 2, note, note).
index((scrap_every), 1, note, note).
index((scrap_every), 2, note, note).
index((scrap_first), 1, note, note).
index((scrap_first), 2, note, note).
index((contains_term), 2, occurs, occurs).
index((contains_var), 2, occurs, occurs).
index((free_of_term), 2, occurs, occurs).
index((free_of_var), 2, occurs, occurs).
index((occurrences_of_term), 3, occurs, occurs).
index((occurrences_of_var), 3, occurs, occurs).
index((sub_term), 2, occurs, occurs).
index((open_files), 2, open_files, open_files).
index((open_null_input), 1, open_files, open_files).
index((open_files), 2, open_files, openfiles).
index((open_null_input), 1, open_files, openfiles).
index((number_order), 3, order, order).
index((ordset_order), 3, order, order).
index((set_order), 3, order, order).
index((term_order), 3, order, order).
index((ordered), 1, ordered, ordered).
index((ordered), 2, ordered, ordered).
index((max_member), 2, ordered, ordered).
index((min_member), 2, ordered, ordered).
index((max_member), 3, ordered, ordered).
index((min_member), 3, ordered, ordered).
index((select_max), 3, ordered, ordered).
index((select_max), 4, ordered, ordered).
index((select_min), 3, ordered, ordered).
index((select_min), 4, ordered, ordered).
index((decreasing_prefix), 3, ordprefix, ordprefix).
index((decreasing_prefix), 4, ordprefix, ordprefix).
index((increasing_prefix), 3, ordprefix, ordprefix).
index((increasing_prefix), 4, ordprefix, ordprefix).
index((is_ordset), 1, ordsets, ordsets).
index((list_to_ord_set), 2, ordsets, ordsets).
index((ord_add_element), 3, ordsets, ordsets).
index((ord_del_element), 3, ordsets, ordsets).
index((ord_disjoint), 2, ordsets, ordsets).
index((ord_disjoint_union), 3, ordsets, ordsets).
index((ord_intersect), 2, ordsets, ordsets).
index((ord_intersect), 3, ordsets, ordsets).
index((ord_intersection), 3, ordsets, ordsets).
index((ord_intersection), 2, ordsets, ordsets).
index((ord_seteq), 2, ordsets, ordsets).
index((ord_setproduct), 3, ordsets, ordsets).
index((ord_subset), 2, ordsets, ordsets).
index((ord_subtract), 3, ordsets, ordsets).
index((ord_symdiff), 3, ordsets, ordsets).
index((ord_union), 3, ordsets, ordsets).
index((ord_union), 2, ordsets, ordsets).
index((ord_union), 4, ordsets, ordsets).
index((assoc_cons), 3, pairup, pairup).
index((assoc_list), 3, pairup, pairup).
index((assoc_pair), 3, pairup, pairup).
index((first_cons), 3, pairup, pairup).
index((first_list), 3, pairup, pairup).
index((first_pair), 3, pairup, pairup).
index((first_side), 3, pairup, pairup).
index((first_cons), 4, pairup, pairup).
index((first_list), 4, pairup, pairup).
index((first_pair), 4, pairup, pairup).
index((first_side), 4, pairup, pairup).
index((pairup_cons), 3, pairup, pairup).
index((pairup_list), 3, pairup, pairup).
index((pairup_pair), 3, pairup, pairup).
index((pairup_side), 3, pairup, pairup).
index((select_cons), 4, pairup, pairup).
index((select_list), 4, pairup, pairup).
index((select_pair), 4, pairup, pairup).
index((select_side), 4, pairup, pairup).
index((select_cons), 5, pairup, pairup).
index((select_list), 5, pairup, pairup).
index((select_pair), 5, pairup, pairup).
index((select_side), 5, pairup, pairup).
index((value_cons), 3, pairup, pairup).
index((value_list), 3, pairup, pairup).
index((value_pair), 3, pairup, pairup).
index((value_side), 3, pairup, pairup).
index((popen), 3, pipe, pipe).
index((set_plot), 1, plot, plot).
index((close_plot), 0, plot, plot).
index((flush_plot), 0, plot, plot).
index((erase_plot), 0, plot, plot).
index((move), 1, plot, plot).
index((move), 2, plot, plot).
index((cont), 1, plot, plot).
index((cont), 2, plot, plot).
index((point), 1, plot, plot).
index((point), 2, plot, plot).
index((line), 2, plot, plot).
index((line), 4, plot, plot).
index((space), 2, plot, plot).
index((space), 4, plot, plot).
index((circle), 2, plot, plot).
index((circle), 3, plot, plot).
index((arc), 3, plot, plot).
index((arc), 6, plot, plot).
index((label), 1, plot, plot).
index((linemod), 1, plot, plot).
index((polygon), 1, plot, plot).
index((polygon), 2, plot, plot).
index((polyline), 1, plot, plot).
index((polyline), 2, plot, plot).
index((pp_tree), 1, pp_tree, pp_tree).
index((pp_term), 1, pp_tree, pp_tree).
index((ps_tree), 1, pp_tree, pp_tree).
index((pp_tree), 1, pp_tree, pptree).
index((pp_term), 1, pp_tree, pptree).
index((ps_tree), 1, pp_tree, pptree).
index((plausible_chars), 1, print_chars, print_chars).
index((portray_chars), 1, print_chars, print_chars).
index((print_length), 2, print_length, print_length).
index((print_length), 3, print_length, print_length).
index((print_lines), 2, print_length, print_length).
index((tab_to), 1, print_length, print_length).
index((plausible_chars), 1, print_chars, printchars).
index((portray_chars), 1, print_chars, printchars).
index((print_length), 2, print_length, printlength).
index((print_length), 3, print_length, printlength).
index((print_lines), 2, print_length, printlength).
index((tab_to), 1, print_length, printlength).
index((prompt), 1, prompt, prompt).
index((prompted_char), 2, prompt, prompt).
index((prompted_line), 2, prompt, prompt).
index((prompted_line), 3, prompt, prompt).
index((put_file), 1, put_file, put_file).
index((put_file), 1, put_file, putfile).
index((qsort), 2, qsort, qsort).
index((qmsort), 2, qsort, qsort).
index((qkeysort), 2, qsort, qsort).
index((make_queue), 1, queues, queues).
index((join_queue), 3, queues, queues).
index((list_join_queue), 3, queues, queues).
index((jump_queue), 3, queues, queues).
index((list_jump_queue), 3, queues, queues).
index((head_queue), 2, queues, queues).
index((serve_queue), 3, queues, queues).
index((length_queue), 2, queues, queues).
index((empty_queue), 1, queues, queues).
index((is_queue), 1, queues, queues).
index((portray_queue), 1, queues, queues).
index((list_to_queue), 2, queues, queues).
index((queue_to_list), 2, queues, queues).
index((getrand), 1, random, random).
index((setrand), 1, random, random).
index((maybe), 0, random, random).
index((maybe), 1, random, random).
index((maybe), 2, random, random).
index((random), 1, random, random).
index((random), 3, random, random).
index((random_graph), 3, random, random).
index((random_numlist), 4, random, random).
index((random_member), 2, random, random).
index((random_select), 3, random, random).
index((random_subseq), 3, random, random).
index((random_permutation), 2, random, random).
index((random_perm2), 4, random, random).
index((cons_rs), 3, ranstk, ranstk).
index((empty_rs), 1, ranstk, ranstk).
index((index_rs), 3, ranstk, ranstk).
index((length_rs), 2, ranstk, ranstk).
index((top_rs), 2, ranstk, ranstk).
index((portray_rs), 1, ranstk, ranstk).
index((portable_gread), 1, read, read).
index((portable_gread), 2, read, read).
index((portable_read), 1, read, read).
index((portable_read), 2, read, read).
index((bind_named_variables), 2, read, read).
index((prompted_constant), 2, read_constant, read_const).
index((prompted_constants), 2, read_constant, read_const).
index((read_constant), 1, read_constant, read_const).
index((read_constant), 2, read_constant, read_const).
index((read_constants), 1, read_constant, read_const).
index((read_constants), 2, read_constant, read_const).
index((skip_constant), 0, read_constant, read_const).
index((skip_constant), 1, read_constant, read_const).
index((skip_constants), 1, read_constant, read_const).
index((skip_constants), 2, read_constant, read_const).
index((read_in), 1, read_in, read_in).
index((case_shift), 2, read_sent, read_sent).
index((chars_to_words), 2, read_sent, read_sent).
index((read_line), 1, read_sent, read_sent).
index((read_sent), 1, read_sent, read_sent).
index((read_until), 2, read_sent, read_sent).
index((trim_blanks), 2, read_sent, read_sent).
index((prompted_constant), 2, read_constant, readconst).
index((prompted_constants), 2, read_constant, readconst).
index((read_constant), 1, read_constant, readconst).
index((read_constant), 2, read_constant, readconst).
index((read_constants), 1, read_constant, readconst).
index((read_constants), 2, read_constant, readconst).
index((skip_constant), 0, read_constant, readconst).
index((skip_constant), 1, read_constant, readconst).
index((skip_constants), 1, read_constant, readconst).
index((skip_constants), 2, read_constant, readconst).
index((read_in), 1, read_in, readin).
index((case_shift), 2, read_sent, readsent).
index((chars_to_words), 2, read_sent, readsent).
index((read_line), 1, read_sent, readsent).
index((read_sent), 1, read_sent, readsent).
index((read_until), 2, read_sent, readsent).
index((trim_blanks), 2, read_sent, readsent).
index((rem_create), 2, rem, rem).
index((rem_add_link), 4, rem, rem).
index((rem_equivalent), 3, rem, rem).
index((affirm), 2, retract, retract).
index((affirm), 3, retract, retract).
index((affirma), 2, retract, retract).
index((affirma), 3, retract, retract).
index((affirmz), 2, retract, retract).
index((affirmz), 3, retract, retract).
index((affirmed), 2, retract, retract).
index((affirmed), 3, retract, retract).
index((asserted), 1, retract, retract).
index((asserted), 2, retract, retract).
index((deny), 2, retract, retract).
index((deny_every), 1, retract, retract).
index((deny_every), 2, retract, retract).
index((deny_first), 1, retract, retract).
index((deny_first), 2, retract, retract).
index((make_defined), 1, retract, retract).
index((make_dynamic), 1, retract, retract).
index((record), 2, retract, retract).
index((record), 3, retract, retract).
index((recorda), 2, retract, retract).
index((recordz), 2, retract, retract).
index((recorded), 2, retract, retract).
index((retract_every), 1, retract, retract).
index((retract_first), 1, retract, retract).
index((wipe), 2, retract, retract).
index((wipe_every), 1, retract, retract).
index((wipe_every), 2, retract, retract).
index((wipe_first), 1, retract, retract).
index((wipe_first), 2, retract, retract).
index((same_functor), 2, same_functor, same_functor).
index((same_functor), 3, same_functor, same_functor).
index((same_functor), 4, same_functor, same_functor).
index((same_functor), 2, same_functor, samefunctor).
index((same_functor), 3, same_functor, samefunctor).
index((same_functor), 4, same_functor, samefunctor).
index((keymerge), 3, samsort, samsort).
index((merge), 3, samsort, samsort).
index((merge), 4, samsort, samsort).
index((samkeysort), 2, samsort, samsort).
index((samsort), 2, samsort, samsort).
index((samsort), 3, samsort, samsort).
index((bag_of), 3, setof, setof).
index((bag_of_all), 3, setof, setof).
index((grouped_bag_of), 4, setof, setof).
index((set_of), 3, setof, setof).
index((set_of_all), 3, setof, setof).
index((grouped_set_of), 4, setof, setof).
index((add_element), 3, sets, sets).
index((del_element), 3, sets, sets).
index((is_set), 1, sets, sets).
index((disjoint), 2, sets, sets).
index((disjoint_union), 3, sets, sets).
index((intersect), 2, sets, sets).
index((intersect), 3, sets, sets).
index((intersection), 2, sets, sets).
index((intersection), 3, sets, sets).
index((list_to_set), 2, sets, sets).
index((pairfrom), 4, sets, sets).
index((power_set), 2, sets, sets).
index((select), 3, sets, sets).
index((selectchk), 3, sets, sets).
index((seteq), 2, sets, sets).
index((setproduct), 3, sets, sets).
index((subset), 2, sets, sets).
index((subtract), 3, sets, sets).
index((symdiff), 3, sets, sets).
index((union), 2, sets, sets).
index((union), 3, sets, sets).
index((union), 4, sets, sets).
index((show_builtins), 0, show, show).
index((show_builtins), 1, show, show).
index((show_records), 0, show, show).
index((show_records), 1, show, show).
index((show_module), 1, show_module, show_module).
index((show_module), 1, show_module, showmodule).
index((save_instances), 2, sofstk, sofstk).
index((save_instances), 3, sofstk, sofstk).
index((list_instances), 1, sofstk, sofstk).
index((list_instances), 2, sofstk, sofstk).
index((list_instances), 3, sofstk, sofstk).
index((conj_instances), 2, sofstk, sofstk).
index((make_key), 3, sofstk, sofstk).
index((full_statistics), 2, statistics, statistics).
index((full_statistics), 0, statistics, statistics).
index((push_style), 0, stchk, stchk).
index((set_style), 2, stchk, stchk).
index((pop_style), 0, stchk, stchk).
index((stream_property), 3, stream_property, stream_property).
index((valid_stream), 1, stream_property, stream_property).
index((stream_property), 3, stream_property, streamproperty).
index((valid_stream), 1, stream_property, streamproperty).
index((atom_chars1), 2, strings, strings).
index((cgensym), 2, strings, strings).
index((char_atom), 2, strings, strings).
index((compare_strings), 3, strings, strings).
index((compare_strings), 4, strings, strings).
index((atomic_list_concat), 2, strings, strings).
index((atomic_list_concat), 3, strings, strings).
index((concat_chars), 2, strings, strings).
index((concat_chars), 3, strings, strings).
%index((concat_string), 2, strings, strings).
%index((concat_string), 3, strings, strings).
index((gensym), 1, strings, strings).
index((gensym), 2, strings, strings).
index((index), 3, strings, strings).
index((midstring), 3, strings, strings).
index((midstring), 4, strings, strings).
index((midstring), 5, strings, strings).
index((midstring), 6, strings, strings).
index((name), 1, strings, strings).
index((name1), 2, strings, strings).
index((nth_char), 3, strings, strings).
index((number_chars1), 2, strings, strings).
index((span_left), 3, strings, strings).
index((span_left), 4, strings, strings).
index((span_left), 5, strings, strings).
index((span_right), 3, strings, strings).
index((span_right), 4, strings, strings).
index((span_right), 5, strings, strings).
index((span_trim), 2, strings, strings).
index((span_trim), 3, strings, strings).
index((span_trim), 5, strings, strings).
index((string), 1, strings, strings).
index((string_append), 3, strings, strings).
index((string_char), 3, strings, strings).
index((string_chars), 2, strings, strings).
index((string_length), 2, strings, strings).
index((string_search), 3, strings, strings).
index((string_size), 2, strings, strings).
index((subchars), 4, strings, strings).
index((subchars), 5, strings, strings).
index((substring), 4, strings, strings).
index((substring), 5, strings, strings).
index((system), 1, strings, strings).
index((subsumes), 2, subsumes, subsumes).
index((variant), 2, subsumes, subsumes).
index((depth_bound), 2, term_depth, term_depth).
index((length_bound), 2, term_depth, term_depth).
index((size_bound), 2, term_depth, term_depth).
index((term_depth), 2, term_depth, term_depth).
index((term_size), 2, term_depth, term_depth).
index((depth_bound), 2, term_depth, termdepth).
index((length_bound), 2, term_depth, termdepth).
index((size_bound), 2, term_depth, termdepth).
index((term_depth), 2, term_depth, termdepth).
index((term_size), 2, term_depth, termdepth).
index((prolog_to_c), 2, terms, terms).
index((erase_c_term), 1, terms, terms).
index((c_to_prolog), 2, terms, terms).
index((time), 3, time_date, time_date).
index((date), 3, time_date, time_date).
index((read_tokens), 1, tokens, tokens).
index((read_tokens), 2, tokens, tokens).
index((get_label), 3, trees, trees).
index((list_to_tree), 2, trees, trees).
index((map_tree), 3, trees, trees).
index((put_label), 4, trees, trees).
index((put_label), 5, trees, trees).
index((tree_size), 2, trees, trees).
index((tree_to_list), 2, trees, trees).
index((true), 1, true, true).
index((fail), 1, true, true).
index((false), 1, true, true).
index((true), 2, true, true).
index((fail), 2, true, true).
index((false), 2, true, true).
index((true), 3, true, true).
index((fail), 3, true, true).
index((false), 3, true, true).
index((true), 4, true, true).
index((fail), 4, true, true).
index((false), 4, true, true).
index((true), 5, true, true).
index((fail), 5, true, true).
index((false), 5, true, true).
index((true), 6, true, true).
index((fail), 6, true, true).
index((false), 6, true, true).
index((twild), 2, twild, twild).
index((twild), 3, twild, twild).
index((chars), 1, types, types).
index((constant), 1, types, types).
index((proper_list), 1, types, types).
index((symbol), 1, types, types).
index((term_type), 2, types, types).
index((must_be), 3, types, types).
index((must_be), 4, types, types).
index((should_be), 3, types, types).
index((should_be), 4, types, types).
index((must_be_atom), 3, types, types).
index((must_be_between), 5, types, types).
index((must_be_callable), 3, types, types).
index((must_be_chars), 3, types, types).
index((must_be_compound), 3, types, types).
index((must_be_constant), 3, types, types).
index((must_be_ground), 3, types, types).
index((must_be_integer), 3, types, types).
index((must_be_nonneg), 3, types, types).
index((must_be_nonvar), 3, types, types).
index((must_be_number), 3, types, types).
index((must_be_oneof), 4, types, types).
index((must_be_proper_list), 3, types, types).
index((must_be_symbol), 3, types, types).
index((must_be_var), 3, types, types).
index((unify), 2, unify, unify).
index((cd), 0, unix, unix).
index((cd), 1, unix, unix).
index((csh), 0, unix, unix).
index((csh), 1, unix, unix).
index((ls), 0, unix, unix).
index((mktemp), 2, unix, unix).
index((mktemp), 3, unix, unix).
index((more), 1, unix, unix).
index((sh), 0, unix, unix).
index((sh), 1, unix, unix).
index((shell), 0, unix, unix).
index((shell), 1, unix, unix).
index((delete), 2, update, update).
index((extend), 2, update, update).
index((modify), 3, update, update).
index((update), 2, update, update).
index((numbervars), 1, varnumbers, varnumbers).
index((varnumbers), 2, varnumbers, varnumbers).
index((varnumbers), 3, varnumbers, varnumbers).
index((list_to_vector), 2, vectors, vectors).
index((list_to_vector), 3, vectors, vectors).
index((lists_to_vectors), 2, vectors, vectors).
index((kill_vector), 1, vectors, vectors).
index((kill_vector), 2, vectors, vectors).
index((make_vector), 3, vectors, vectors).
index((set_vector_element), 3, vectors, vectors).
index((vector_element), 3, vectors, vectors).
index((vector_size), 2, vectors, vectors).
index((vector_to_list), 2, vectors, vectors).
index((make_vset), 2, vsets, vsets).
index((vset_member), 2, vsets, vsets).
index((vset_del_element), 2, vsets, vsets).
index((intersect_vsets), 2, vsets, vsets).
index((portray_vset), 1, vsets, vsets).
index((term_to_tokens), 2, write_tokens, write_tokens).
index((term_to_tokens), 4, write_tokens, write_tokens).
index((term_to_tokens), 2, write_tokens, writetokens).
index((term_to_tokens), 4, write_tokens, writetokens).

index((check), 1, checker, checker).
index((crecord), 2, xrf, xrf).
index((record_public), 1, xrf, xrf).
index((peekAtModule), 3, xrf, xrf).
index((go), 0, xrf, xrf).
index((collect), 1, xrfcol, xrfcol).
index((defn_file), 2, xrfcol, xrfcol).
index((check_filename), 1, xrfdef, xrfdef).
index((check_width), 1, xrfdef, xrfdef).
index((is_system), 1, xrfdef, xrfdef).
index((load), 1, xrfdef, xrfdef).
index((load_list), 1, xrfdef, xrfdef).
index((load_file), 1, xrfdef, xrfdef).
index((known_file), 1, xrfdef, xrfdef).
index((known_pred), 3, xrfdef, xrfdef).
index((update_declarations), 3, xrfmod, xrfmod).
index((do_export_modules), 2, xrfout, xrfout).
index((do_import_modules), 1, xrfout, xrfout).
index((do_output), 1, xrfout, xrfout).
index((writes), 1, xrfout, xrfout).
index((get_crf), 3, xrftty, xrftty).
index((get_globals_file), 2, xrftty, xrftty).
index((get_title), 1, xrftty, xrftty).
index((get_update_module_declarations), 1, xrftty, xrftty).
index((get_width), 1, xrftty, xrftty).
index((readtonl), 1, xrftty, xrftty).

% old line 1318, changed according to AIIL's instructions for QP3.2
% bts, 12/94
% index((expand_file_name), 2, xrftty, xrftty).
index((expand_file_name), 2, pce_qux, pce_qux).

index((make_extended_file_name), 2, xrftty, xrftty).
index((check_file_exists), 1, xrftty, xrftty).
index((prolog_file_exists), 3, xrftty, xrftty).
index((see_chek), 1, xrftty, xrftty).
index((tell_chek), 1, xrftty, xrftty).
index((warn), 2, xrftty, xrftty).
index((warning), 1, xrftty, xrftty).

index((socket_io_open_input), 2, socket_io, socket_io).
index((socket_io_open_output), 2, socket_io, socket_io).
index((tcp_trace), 2, tcp, tcp).
index((tcp_watch_user), 2, tcp, tcp).
index((tcp_listen), 1, tcp, tcp).
index((tcp_listen), 2, tcp, tcp).
index((tcp_listen_at_port), 2, tcp, tcp).
index((tcp_address_from_file), 2, tcp, tcp).
index((tcp_address_from_shell), 3, tcp, tcp).
index((tcp_address_from_shell), 4, tcp, tcp).
index((tcp_connect), 2, tcp, tcp).
index((tcp_connect), 3, tcp, tcp).
index((tcp_connected), 1, tcp, tcp).
index((tcp_shutdown), 1, tcp, tcp).
index((tcp_reset), 0, tcp, tcp).
index((tcp_select), 1, tcp, tcp).
index((tcp_select), 2, tcp, tcp).
index((tcp_send), 2, tcp, tcp).
index((tcp_now), 1, tcp, tcp).
index((tcp_time_plus), 3, tcp, tcp).
index((tcp_schedule_wakeup), 2, tcp, tcp).
index((tcp_cancel_wakeup), 2, tcp, tcp).
index((tcp_date_timeval), 2, tcp, tcp).
index((tcp_daily), 4, tcp, tcp).
index((tcp_input_stream), 2, tcp, tcp).
index((tcp_output_stream), 2, tcp, tcp).
index((tcp_select_from), 1, tcp, tcp).
index((tcp_select_from), 2, tcp, tcp).
index((tcp_nfs_connect), 3, tcp, tcp).
index((tcp_rsh_connect), 4, tcp, tcp).
index((tcp_select_keyboard), 2, tcp, tcp).
index((tcp_wakeup), 2, tcp, tcp).

index((save_ipc_servant), 1, ccallqp, ccallqp).
index((msg_trace), 2, ccallqp, ccallqp).
index((connect_and_serve_xdr), 0, ccallqp, ccallqp).
index((save_servant), 1, qpcallqp, qpcallqp).
index((create_servant), 2, qpcallqp, qpcallqp).
index((create_servant), 3, qpcallqp, qpcallqp).
index((shutdown_servant), 0, qpcallqp, qpcallqp).
index((call_servant), 1, qpcallqp, qpcallqp).
index((bag_of_all_servant), 3, qpcallqp, qpcallqp).
index((set_of_all_servant), 3, qpcallqp, qpcallqp).
index((reset_servant), 0, qpcallqp, qpcallqp).
index((msg_trace), 2, qpcallqp, qpcallqp).
index((start_servant), 0, qpcallqp, qpcallqp).

index((associate), 3, protalk, protalk).
index((associations), 2, protalk, protalk).
index((attribute), 2, protalk, protalk).
index((attributes), 2, protalk, protalk).
index((bassociate), 3, protalk, protalk).
index((bstore), 3, protalk, protalk).
index((change), 4, protalk, protalk).
index((class), 1, protalk, protalk).
index((classid), 2, protalk, protalk).
index((class_object), 2, protalk, protalk).
index((delegate_method), 1, protalk, protalk).
index((delete_values), 2, protalk, protalk).
index((destroy_object), 1, protalk, protalk).
index((disassociate), 3, protalk, protalk).
index((disassociate1), 3, protalk, protalk).
index((fetch), 3, protalk, protalk).
index((fetch1), 3, protalk, protalk).
index((fetchall), 3, protalk, protalk).
index((generic_method), 1, protalk, protalk).
index((is_attribute), 2, protalk, protalk).
index((is_class), 1, protalk, protalk).
index((is_object), 1, protalk, protalk).
index((is_object), 2, protalk, protalk).
index((is_protalk_object), 1, protalk, protalk).
index((is_registered), 2, protalk, protalk).
index((is_registered_protalk), 2, protalk, protalk).
index((is_registered_prowindows), 2, protalk, protalk).
index((new_class), 1, protalk, protalk).
index((new_class), 2, protalk, protalk).
index((new_class), 3, protalk, protalk).
index((new_class), 4, protalk, protalk).
index((new_id), 1, protalk, protalk).
index((new_instance), 2, protalk, protalk).
index((object_initialize), 2, protalk, protalk).
index((object_method), 1, protalk, protalk).
index((preassociate), 3, protalk, protalk).
index((protalk), 0, protalk, protalk).
index((protalk_listing), 0, protalk, protalk).
index((protalk_listing), 1, protalk, protalk).
index((prowindows_name), 1, protalk, protalk).
index((prowindows_name), 2, protalk, protalk).
index((protalk_get), 3, protalk, protalk).
index((protalk_get1), 3, protalk, protalk).
index((protalk_instance), 2, protalk, protalk).
index((protalk_instance_r), 2, protalk, protalk).
index((protalk_instances), 2, protalk, protalk).
index((protalk_instances_r), 2, protalk, protalk).
index((protalk_new), 2, protalk, protalk).
index((protalk_new), 3, protalk, protalk).
index((protalk_object), 1, protalk, protalk).
index((protalk_object), 2, protalk, protalk).
index((protalk_objects), 1, protalk, protalk).
index((protalk_send), 2, protalk, protalk).
index((protalk_send), 3, protalk, protalk).
index((protalk_send1), 2, protalk, protalk).
index((protalk_send1), 3, protalk, protalk).
index((redef_action), 2, protalk, protalk).
index((register), 2, protalk, protalk).
index((registered), 2, protalk, protalk).
index((registered_protalk), 2, protalk, protalk).
index((registered_prowindows), 2, protalk, protalk).
index((r_associate), 3, protalk, protalk).
index((r_class), 1, protalk, protalk).
index((r_class), 2, protalk, protalk).
index((r_destroy), 1, protalk, protalk).
index((r_disassociate), 3, protalk, protalk).
index((r_fetch), 3, protalk, protalk).
index((r_fetchall), 3, protalk, protalk).
index((r_get), 3, protalk, protalk).
index((r_get1), 3, protalk, protalk).
index((r_listing), 0, protalk, protalk).
index((r_listing), 1, protalk, protalk).
index((r_listing_protalk), 0, protalk, protalk).
index((r_listing_prowindows), 0, protalk, protalk).
index((r_new), 2, protalk, protalk).
index((r_new), 3, protalk, protalk).
index((r_new_id), 3, protalk, protalk).
index((r_object), 1, protalk, protalk).
index((r_object), 2, protalk, protalk).
index((r_preassociate), 3, protalk, protalk).
index((r_send), 2, protalk, protalk).
index((r_send1), 2, protalk, protalk).
index((r_send), 3, protalk, protalk).
index((r_send1), 3, protalk, protalk).
index((r_store), 3, protalk, protalk).
index((standard_initialize), 3, protalk, protalk).
index((store), 3, protalk, protalk).
index((store_list), 3, protalk, protalk).
index((stuff), 1, protalk, protalk).
index((unregister), 1, protalk, protalk).

index((foreign_type), 2, structs, structs).
index((get_contents), 3, structs, structs).
index((put_contents), 3, structs, structs).
index((get_address), 3, structs, structs).
index((new), 2, structs, structs).
index((new), 3, structs, structs).
index((dispose), 1, structs, structs).
index((cast), 3, structs, structs).
index((null_foreign_term), 2, structs, structs).
index((type_definition), 2, structs, structs).
index((atomic_type), 1, structs, structs).
index((atomic_type), 2, structs, structs).
index((atomic_type), 3, structs, structs).
index((structs_to_c), 1, structs_to_c, structs_to_c).
index((structs_to_c), 2, structs_to_c, structs_to_c).

index((side_pattern), 3, area, area).
index((dialog), 0, dialog, dialog).
index((pcedemo), 0, pce_demo, pce_demo).
index((emacs), 0, emacs, pce_emacs).
index((emacs), 1, emacs, pce_emacs).
index((start_emacs), 0, emacs, pce_emacs).
index((declare_emacs_mode), 2, emacs_extend, emacs_extend).
index((declare_emacs_mode), 3, emacs_extend, emacs_extend).
index((emacs_begin_mode), 5, emacs_extend, emacs_extend).
index((emacs_extend_mode), 2, emacs_extend, emacs_extend).
index((emacs_end_mode), 0, emacs_extend, emacs_extend).
index((emacs_tag), 3, emacs_tags, emacs_tags).
index((emacs_tag_file), 1, emacs_tags, emacs_tags).
index((emacs_init_tags), 1, emacs_tags, emacs_tags).
index((emacs_complete_tag), 2, emacs_tags, emacs_tags).
index((show_key_bindings), 1, key_binding, keybinding).
index((make_dialog), 2, pce_make_dialog, make_dialog).
index((new), 2, pce, pce).
index((free), 1, pce, pce).
index((send), 2, pce, pce).
index((send), 3, pce, pce).
index((send), 4, pce, pce).
index((send), 5, pce, pce).
index((send), 6, pce, pce).
index((send), 7, pce, pce).
index((send), 8, pce, pce).
index((send), 9, pce, pce).
index((send), 10, pce, pce).
index((send), 11, pce, pce).
index((send), 12, pce, pce).
index((get), 3, pce, pce).
index((get), 4, pce, pce).
index((get), 5, pce, pce).
index((get), 6, pce, pce).
index((get), 7, pce, pce).
index((get), 8, pce, pce).
index((get), 9, pce, pce).
index((get), 10, pce, pce).
index((get), 11, pce, pce).
index((get), 12, pce, pce).
index((get), 13, pce, pce).
index((object), 1, pce, pce).
index((object), 2, pce, pce).
index((pce_global), 2, pce, pce).
index((pce_autoload), 2, pce, pce).
index((pce_autoload_all), 0, pce, pce).
index((pce_begin_class), 2, pce, pce).
index((pce_begin_class), 3, pce, pce).
index((pce_extend_class), 1, pce, pce).
index((pce_end_class), 0, pce, pce).
index((default), 3, pce, pce).
index((pce_group), 1, pce, pce).
index((pce_term_expansion), 2, pce, pce).
index((pce_compiling), 1, pce, pce).
index((pce_catch_error), 2, pce, pce).
index((generate_cpp_class_header_file), 0, pce_cpp_header, pce_cxx_headers).
index((debugpce), 0, pce_debug, pce_debug).
index((debugpce), 1, pce_debug, pce_debug).
index((nodebugpce), 0, pce_debug, pce_debug).
index((nodebugpce), 1, pce_debug, pce_debug).
index((tracepce), 0, pce_debug, pce_debug).
index((notracepce), 0, pce_debug, pce_debug).
index((tracepce), 1, pce_debug, pce_debug).
index((notracepce), 1, pce_debug, pce_debug).
index((breakpce), 1, pce_debug, pce_debug).
index((nobreakpce), 1, pce_debug, pce_debug).
index((spypce), 1, pce_debug, pce_debug).
index((nospypce), 1, pce_debug, pce_debug).
index((checkpce), 0, pce_debug, pce_debug).
index((show_slots), 1, pce_debug, pce_debug).
index((pcerefer), 1, pce_debug, pce_debug).
index((pcerefer), 2, pce_debug, pce_debug).
index((editpce), 1, pce_edit, pce_edit).
index((manpce), 0, pce_manual, pce_manual).
index((manpce), 1, pce_manual, pce_manual).
index((postscript), 2, pce_postscript, pce_postscript).
index((prompter), 2, pce_prompter, pce_prompter).
index((pce_renew), 1, pce_renew, pce_renew).
index((pce_require), 1, pce_require, pce_require).
index((pce_require), 3, pce_require, pce_require).
index((emacs_require), 1, pce_require, pce_require).
index((pce_require_all), 1, pce_require, pce_require).
index((pce_server), 1, pce_server, pce_server).
index((get_object), 3, pce_util, pce_util).
index((get_object), 4, pce_util, pce_util).
index((get_object), 5, pce_util, pce_util).
index((get_object), 6, pce_util, pce_util).
index((get_object), 7, pce_util, pce_util).
index((get_object), 8, pce_util, pce_util).
index((get_object), 9, pce_util, pce_util).
index((get_object), 10, pce_util, pce_util).
index((get_object), 11, pce_util, pce_util).
index((get_object), 12, pce_util, pce_util).
index((get_object), 13, pce_util, pce_util).
index((send_list), 2, pce_util, pce_util).
index((send_list), 3, pce_util, pce_util).
index((get_chain), 3, pce_util, pce_util).
index((chain_list), 2, pce_util, pce_util).
index((pcedraw), 0, pce_draw, pcedraw).
index((pcedraw), 1, pce_draw, pcedraw).
index((draw_toplevel), 0, pce_draw, pcedraw).
index((draw_begin_shape), 4, pce_draw, pcedraw).
index((draw_end_shape), 0, pce_draw, pcedraw).
index((show_help_hook), 2, pl_show_help, show_help).
index((portray_object), 1, pce_portray, portray_object).
index((portray_object), 2, pce_portray, portray_object).
index((string_search), 3, arity_strings, arity_strings).
index((string_search), 4, arity_strings, arity_strings).
index((arity_substring), 4, arity_strings, arity_strings).
index((nth_char), 3, arity_strings, arity_strings).
index((string_length), 2, arity_strings, arity_strings).
index((concat), 3, arity_strings, arity_strings).
index((concat), 2, arity_strings, arity_strings).
index((string_term), 2, arity_strings, arity_strings).
index((atom_string), 2, arity_strings, arity_strings).
index((int_text), 2, arity_strings, arity_strings).
index((float_text), 3, arity_strings, arity_strings).
index((list_text), 2, arity_strings, arity_strings).
index((read_string), 2, arity_strings, arity_strings).
index((read_string), 3, arity_strings, arity_strings).
index((read_line), 1, arity_strings, arity_strings).
index((read_line), 2, arity_strings, arity_strings).
index((string_search), 3, arity_strings, aritystrings).
index((string_search), 4, arity_strings, aritystrings).
index((arity_substring), 4, arity_strings, aritystrings).
index((nth_char), 3, arity_strings, aritystrings).
index((string_length), 2, arity_strings, aritystrings).
index((concat), 3, arity_strings, aritystrings).
index((concat), 2, arity_strings, aritystrings).
index((string_term), 2, arity_strings, aritystrings).
index((atom_string), 2, arity_strings, aritystrings).
index((int_text), 2, arity_strings, aritystrings).
index((float_text), 3, arity_strings, aritystrings).
index((list_text), 2, arity_strings, aritystrings).
index((read_string), 2, arity_strings, aritystrings).
index((read_string), 3, arity_strings, aritystrings).
index((read_line), 1, arity_strings, aritystrings).
index((read_line), 2, arity_strings, aritystrings).
index((remove), 3, lpa, lpa).
index((select), 3, lpa, lpa).
index((remove_all), 3, lpa, lpa).
index((subtract), 3, lpa, lpa).
index((on), 2, lpa, lpa).
index((member), 2, lpa, lpa).
index((p_functor), 3, lpa, lpa).
index((p_sin), 2, lpa, lpa).
index((p_asin), 2, lpa, lpa).
index((p_cos), 2, lpa, lpa).
index((p_acos), 2, lpa, lpa).
index((p_tan), 2, lpa, lpa).
index((p_atan), 2, lpa, lpa).
index((p_log), 2, lpa, lpa).
index((p_exp), 2, lpa, lpa).
index((p_log), 3, lpa, lpa).
index((p_exp), 3, lpa, lpa).
index((p_abs), 2, lpa, lpa).
index((p_sign), 2, lpa, lpa).
index((p_sqrt), 2, lpa, lpa).
index((deg_rad), 2, lpa, lpa).
index((pi), 1, lpa, lpa).
index((load_program), 1, lpa, lpa).
index((reverse), 2, lpa, lpa).
index((kill), 1, lpa, lpa).
index((dec10_abolish), 2, lpa, lpa).
index((lst), 1, lpa, lpa).
index((atom), 2, lpa, lpa).
index((environment), 1, lpa, lpa).
index((sys), 1, lpa, lpa).
index((def), 1, lpa, lpa).
index((dict), 1, lpa, lpa).
index((cdef), 1, lpa, lpa).
index((cdict), 1, lpa, lpa).
index((idef), 1, lpa, lpa).
index((idict), 1, lpa, lpa).
index((pdef), 1, lpa, lpa).
index((sdef), 1, lpa, lpa).
index((sdict), 1, lpa, lpa).
index((adict), 1, lpa, lpa).
index((fdict), 1, lpa, lpa).
index((gdict), 1, lpa, lpa).
index((mdict), 1, lpa, lpa).
index((wdict), 1, lpa, lpa).
index((open_file), 3, lpa, lpa).
index((p_close), 1, lpa, lpa).
index((writev), 2, lpa, lpa).
index((writev), 3, lpa, lpa).
index((writeq), 3, lpa, lpa).
index((writeseq), 1, lpa, lpa).
index((writeseq), 2, lpa, lpa).
index((writeqseq), 1, lpa, lpa).
index((writeqseq), 2, lpa, lpa).
index((writeqseq), 3, lpa, lpa).
index((writenl), 1, lpa, lpa).
index((writenl), 2, lpa, lpa).
index((writeqnl), 1, lpa, lpa).
index((writeqnl), 2, lpa, lpa).
index((writeqnl), 3, lpa, lpa).
index((writeseqnl), 1, lpa, lpa).
index((writeseqnl), 2, lpa, lpa).
index((writeqseqnl), 1, lpa, lpa).
index((writeqseqnl), 2, lpa, lpa).
index((writeqseqnl), 3, lpa, lpa).
index((dec10_display), 1, lpa, lpa).
index((p_get), 1, lpa, lpa).
index((charof), 2, lpa, lpa).
index((char_atoms), 2, lpa, lpa).
index((stringof), 2, lpa, lpa).
index((textof), 2, lpa, lpa).
index((gread), 1, lpa, lpa).
index((prompt_gread), 2, lpa, lpa).
index((gread), 2, lpa, lpa).
index((prompt_gread), 3, lpa, lpa).
index((gread), 3, lpa, lpa).
index((prompt_read), 2, lpa, lpa).
index((prompt_yesno), 1, lpa, lpa).
index((prompt_message), 1, lpa, lpa).
index((prompt_error), 1, lpa, lpa).
index((prompt_warning), 1, lpa, lpa).
index((beep), 1, lpa, lpa).
index((beep), 2, lpa, lpa).
index((one), 1, lpa, lpa).
index((force), 1, lpa, lpa).
index((not), 1, lpa, lpa).
index((\=), 2, lpa, lpa).
index((apply), 2, lpa, lpa).
index((p_call), 1, lpa, lpa).
index((p_call), 2, lpa, lpa).
index((p_call), 3, lpa, lpa).
index((p_call), 4, lpa, lpa).
index((p_call), 5, lpa, lpa).
index((p_call), 6, lpa, lpa).
index((p_call), 7, lpa, lpa).
index((mem), 3, lpa, lpa).
index((keysort), 3, lpa, lpa).
index((sort), 3, lpa, lpa).
index((sort), 4, lpa, lpa).
index((ems), 0, lpa, lpa).
index((crarray), 4, lpa, lpa).
index((crarray), 5, lpa, lpa).
index((szarray), 3, lpa, lpa).
index((szarray), 4, lpa, lpa).
index((aload), 1, lpa, lpa).
index((asave), 2, lpa, lpa).
index((setblk), 6, lpa, lpa).
index((getblk), 6, lpa, lpa).
index((rotblk), 7, lpa, lpa).
index((schline), 5, lpa, lpa).
index((schline), 6, lpa, lpa).
index((get_prop), 3, lpa, lpa).
index((recall), 2, lpa, lpa).
index((default), 3, lpa, lpa).
index((set_prop), 3, lpa, lpa).
index((remember), 2, lpa, lpa).
index((del_prop), 2, lpa, lpa).
index((forget), 1, lpa, lpa).
index((get_cons), 2, lpa, lpa).
index((del_cons), 1, lpa, lpa).
index((get_props), 2, lpa, lpa).
index((del_props), 1, lpa, lpa).
index((p_date), 3, lpa, lpa).
index((p_datime), 6, lpa, lpa).
index((p_time), 3, lpa, lpa).
index((run_time), 2, lpa, lpa).
index((run_time), 3, lpa, lpa).
index((toground), 2, lpa, lpa).
index((toground), 3, lpa, lpa).
index((toground), 4, lpa, lpa).
index((toground), 5, lpa, lpa).
index((tohollow), 3, lpa, lpa).
index((tohollow), 4, lpa, lpa).
index((varsin), 2, lpa, lpa).
index((file_exists), 1, lpa, lpa).
index((delete_file), 1, lpa, lpa).
index((rename_file), 2, lpa, lpa).
index((current_directory), 1, lpa, lpa).
index((set_directory), 1, lpa, lpa).
